@@ -2,6 +2,8 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
+from tox.config.types import MissingRequiredConfigKeyError
+
 from .ini import IniSource
 from .ini_section import IniSection
 
@@ -10,7 +12,7 @@ if TYPE_CHECKING:
 
 
 class SetupCfg(IniSource):
-    """Configuration sourced from a tox.ini file."""
+    """Configuration sourced from a setup.cfg file."""
 
     CORE_SECTION = IniSection("tox", "tox")
     FILENAME = "setup.cfg"
@@ -18,7 +20,7 @@ class SetupCfg(IniSource):
     def __init__(self, path: Path) -> None:
         super().__init__(path)
         if not self._parser.has_section(self.CORE_SECTION.key):
-            raise ValueError
+            raise MissingRequiredConfigKeyError(path)
 
 
 __all__ = ("SetupCfg",)
