@@ -16,10 +16,11 @@ from tox.report import HandledError
 from tox.session.cmd.run.single import run_command_set
 from tox.tox_env.errors import Fail, Skip
 from tox.tox_env.python.pip.req_file import PythonDeps
+from tox.tox_env.python.pylock import Pylock
 from tox.tox_env.runner import RunToxEnv
 
 from .api import Python
-from .dependency_groups import resolve
+from .dependency_groups import resolve as resolve_dependency_groups
 from .extras import resolve_extras_static
 
 if TYPE_CHECKING:
@@ -53,6 +54,27 @@ class PythonRun(Python, RunToxEnv, ABC):
             desc="dependency groups to install of the target package",
             post_process=_normalize_extras,
         )
+        self.conf.add_config(
+            keys=["extras"],
+            of_type=set[str],
+            default=set(),
+            desc="extras to install of the target package",
+            post_process=_normalize_extras,
+        )
+
+        def _validate_pylock_not_with_deps(value: str) -> str:
+            if value and self.conf["deps"].lines():
+                msg = "cannot use both 'deps' and 'pylock' in the same environment"
+                raise Fail(msg)
+            return value
+
+        self.conf.add_config(
+            keys=["pylock"],
+            of_type=str,
+            default="",
+            desc="PEP 751 pylock.toml lock file path to install locked dependencies from",
+            post_process=_validate_pylock_not_with_deps,
+        )
         self.conf.add_config(
             keys=["extra_setup_commands"],
             of_type=list[Command],
@@ -87,12 +109,7 @@ class PythonRun(Python, RunToxEnv, ABC):
             else:
                 self.conf.add_config(keys="package", of_type=str, default=self.default_pkg_type, desc=desc)
 
-        pkg_type = self.pkg_type
-        if pkg_type == "skip":
-            return False
-
-        add_extras_to_env(self.conf)
-        return True
+        return self.pkg_type != "skip"
 
     @property
     def default_pkg_type(self) -> str:
@@ -129,8 +146,11 @@ class PythonRun(Python, RunToxEnv, ABC):
         if getattr(self.options, "skip_env_install", False):
             logging.warning("skip installing dependencies and package")
             return
-        self._install_deps()
-        self._install_dependency_groups()
+        if self.conf["pylock"]:
+            self._install_pylock()
+        else:
+            self._install_deps()
+            self._install_dependency_groups()
 
     def _install_deps(self) -> None:
         requirements_file: PythonDeps = self.conf["deps"]
@@ -144,9 +164,31 @@ class PythonRun(Python, RunToxEnv, ABC):
             root: Path = self.core["package_root"]
         except KeyError:
             root = self.core["tox_root"]
-        requirements = resolve(root, groups)
+        requirements = resolve_dependency_groups(root, groups)
         self._install(list(requirements), PythonRun.__name__, "dependency-groups")
 
+    def _install_pylock(self) -> None:
+        pylock_path: str = self.conf["pylock"]
+        try:
+            root: Path = self.core["package_root"]
+        except KeyError:
+            root = self.core["tox_root"]
+        if not (path := root / pylock_path).exists():
+            msg = f"pylock file {pylock_path!r} not found at {path}"
+            raise Fail(msg)
+        info = self.base_python
+        marker_env = {
+            "implementation_name": info.impl_lower,
+            "platform_python_implementation": info.implementation,
+            "python_version": info.version_dot,
+            "python_full_version": f"{info.version_info.major}.{info.version_info.minor}.{info.version_info.micro}",
+            "sys_platform": info.platform,
+        }
+        extras: set[str] = self.conf["extras"]
+        groups: set[str] = self.conf["dependency_groups"]
+        pylock = Pylock(path=path, extras=frozenset(extras), groups=frozenset(groups), marker_env=marker_env)
+        self._install(pylock, PythonRun.__name__, "pylock")
+
     def _setup_with_env(self) -> None:
         super()._setup_with_env()
         self._run_extra_setup_commands()
